==> lxqt-about_1.1.0.orig.tar.xz: lxqt-about-1.1.0/translations/lxqt-about_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="83"/>
        <source>Version: %1</source>
        <translation>版本: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="99"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>基於 Qt 技術打造出的容易使用、進階、快速的桌面環境。</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="101"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>因為 &lt;a %1&gt;Razor-qt&lt;/a&gt; 專案和它的許多貢獻者，讓 LXQt 成為可能。</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="103"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>版權所有: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="105"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>首頁: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="107"/>
        <source>Wiki: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="109"/>
        <source>Development: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="111"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>憑證 :%1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="121"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>LXQt 是由 &lt;a %1&gt;LXQt 團隊和其貢獻者開發&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="123"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>如果你對和我們的開發團隊一起工作有興趣，&lt;a %1&gt;加入我們&lt;/a&gt;。</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation>特別感謝:</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="147"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world. Translations can be done in &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source>About LXQt</source>
        <translation>關於LXQt</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>感謝</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>翻譯</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>技術資訊</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation>複製到剪貼簿</translation>
    </message>
</context>
</TS>

==> lxqt-about-2.0.0.tar.xz: lxqt-about-2.0.0/translations/lxqt-about_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="88"/>
        <source>Version: %1</source>
        <translation>版本: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="104"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>基於 Qt 技術打造出的容易使用、進階、快速的桌面環境。</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="106"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>因為 &lt;a %1&gt;Razor-qt&lt;/a&gt; 專案和它的許多貢獻者，讓 LXQt 成為可能。</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="108"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>版權所有: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="110"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>首頁: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="112"/>
        <source>Wiki: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="114"/>
        <source>Development: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="116"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>憑證 :%1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="126"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>LXQt 是由 &lt;a %1&gt;LXQt 團隊和其貢獻者開發&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="128"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>如果你對和我們的開發團隊一起工作有興趣，&lt;a %1&gt;加入我們&lt;/a&gt;。</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="145"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation>特別感謝:</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="152"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world. Translations can be done in &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation>感謝遍布世界各地的翻譯團隊，使 LXQt 得以翻譯成許多語言。您可以在 &lt;a %1&gt;LXQt-Weblate&lt;/a&gt; 進行翻譯。</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source>About LXQt</source>
        <translation>關於LXQt</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>作者</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>感謝</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>翻譯</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>技術資訊</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation>複製到剪貼簿</translation>
    </message>
</context>
</TS>
